==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Image/Gui/Resources/translations/Image_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+101"/>
      <source>Image</source>
      <translation>Afbeelding</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>Maak beeldvlak ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>Maak een vlakke afbeelding in de 3D-ruimte</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>een vlakke afbeelding maken in de 3D-ruimte</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-50"/>
      <source>Image</source>
      <translation>Afbeelding</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>Openen...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>Open afbeelding weergave</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+333"/>
      <location filename="../../OpenGLImageBox.cpp" line="+385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Ongedefinieerd type kleurruimte om beelden te bekijken</translation>
    </message>
    <message>
      <location line="-1"/>
      <location filename="../../OpenGLImageBox.cpp" line="-1"/>
      <source>Image pixel format</source>
      <translation>Pixelformaat voor afbeelding</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation>Kies oriëntatie</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation>Beeldvlak</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation>XY-vlak</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation>XZ-vlak</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation>YZ-vlak</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation>Richting omkeren</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation>Offset:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+107"/>
      <source>&amp;Fit image</source>
      <translation>&amp;Passend</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>Uitrekken tot grootte weergave venster</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>Schaal &amp;1:1</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Toon de afbeelding op schaal van 1:1</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>&amp;Oorspronkelijke kleur</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>Toon de afbeelding met de oorspronkelijke kleur(en)</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>&amp;Verhelder kleur</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>Toon de afbeelding met verhelderde kleur(en)</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>Standaard</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Ready...</source>
      <translation>Gereed...</translation>
    </message>
    <message>
      <location line="+390"/>
      <source>grey</source>
      <translation>grijs</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>zoom</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>buiten afbeelding</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>Afbeeldingenviewer</translation>
    </message>
    <message>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Afbeeldingen(*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+20"/>
      <location line="+47"/>
      <source>Choose an image file to open</source>
      <translation>Kies een te openen afbeeldingsbestand</translation>
    </message>
    <message>
      <location line="-54"/>
      <location line="+47"/>
      <source>Images</source>
      <translation>Afbeeldingen</translation>
    </message>
    <message>
      <location line="-42"/>
      <location line="+47"/>
      <source>All files</source>
      <translation>Alle bestanden</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error opening image</source>
      <translation>Fout bij openen van afbeelding</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the chosen image</source>
      <translation>De gekozen afbeelding kan niet worden geladen</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Fout geopende afbeelding</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Kon geselecteerde afbeelding niet laden</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Afbeelding</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Image/Gui/Resources/translations/Image_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+101"/>
      <source>Image</source>
      <translation>Afbeelding</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>Maak beeldvlak ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>Maak een vlakke afbeelding in de 3D-ruimte</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>een vlakke afbeelding maken in de 3D-ruimte</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-50"/>
      <source>Image</source>
      <translation>Afbeelding</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>Openen...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>Afbeeldingsweergave openen</translation>
    </message>
  </context>
  <context>
    <name>CmdImageScaling</name>
    <message>
      <location line="+120"/>
      <source>Image</source>
      <translation>Afbeelding</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Scale...</source>
      <translation>Schaal...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Image Scaling</source>
      <translation>Afbeelding schalen</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+333"/>
      <location filename="../../OpenGLImageBox.cpp" line="+385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Ongedefinieerd type kleurruimte om beelden te bekijken</translation>
    </message>
    <message>
      <location line="-1"/>
      <location filename="../../OpenGLImageBox.cpp" line="-1"/>
      <source>Image pixel format</source>
      <translation>Pixelformaat voor afbeelding</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation>Kies oriëntatie</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation>Beeldvlak</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation>XY-vlak</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation>XZ-vlak</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation>YZ-vlak</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation>Richting omkeren</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation>Offset:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+107"/>
      <source>&amp;Fit image</source>
      <translation>&amp;Pas afbeelding</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>Rek het beeld uit zodat het in de weergave past</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>Schaal &amp;1:1</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Toon de afbeelding op schaal van 1:1</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>&amp;Oorspronkelijke kleur</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>Toon de afbeelding met de oorspronkelijke kleur(en)</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>&amp;Verhelder kleur</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>Toon de afbeelding met verhelderde kleur(en)</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>Standaard</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Ready...</source>
      <translation>Gereed...</translation>
    </message>
    <message>
      <location line="+390"/>
      <source>grey</source>
      <translation>grijs</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>zoom</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>buiten afbeelding</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>Afbeeldingenviewer</translation>
    </message>
    <message>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Afbeeldingen(*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-102"/>
      <location line="+47"/>
      <source>Choose an image file to open</source>
      <translation>Kies een afbeeldingsbestand om te openen</translation>
    </message>
    <message>
      <location line="-54"/>
      <location line="+47"/>
      <source>Images</source>
      <translation>Afbeeldingen</translation>
    </message>
    <message>
      <location line="-42"/>
      <location line="+47"/>
      <source>All files</source>
      <translation>Alle bestanden</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error opening image</source>
      <translation>Fout bij openen van de afbeelding</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the chosen image</source>
      <translation>De gekozen afbeelding kan niet worden geladen</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Fout geopende afbeelding</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Kon geselecteerde afbeelding niet laden</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Afbeelding</translation>
    </message>
  </context>
</TS>
